@@ -6,7 +6,7 @@ use warnings::illegalproto ();
 use Moo ();
 use Web::Dispatch::Wrapper ();
 
-our $VERSION = '0.015';
+our $VERSION = '0.016';
 
 sub import {
   my ($class, $app_package) = @_;
@@ -30,6 +30,8 @@ sub _export_into {
   $INC{"${name}.pm"} = 'Set by "use Web::Simple;" invocation';
 }
 
+"Happy 62nd, wherever you are";
+
 =head1 NAME
 
 Web::Simple - A quick and easy way to build simple web applications
@@ -809,5 +811,3 @@ This library is free software and may be distributed under the same terms
 as perl itself.
 
 =cut
-
-1;
